Structs

Returned by every alignment function. The aligned strings have ‘-’ at gaps.

Holds penalties scores. There is no match penalty: matches do not change the score. The penalty for any gap is length * extd_pen + open_pen. The extension pen is also applied when a gap is opened. Penalties should be a positive int.

Used to store and access wavefronts efficiently. T is the type used to store the number of chars matched. U is the type used for diagonals.

Enums

Error type, for alignment errors.

Alignment layers. Used for tracking back.

Traits

Functions

Make a new wavefront grid with the first diagonal of (lo, hi) lo and hi = 0 for a 1-element initial diagonal.