pub struct Backlight { /* private fields */ }Implementations
Sourceimpl Backlight
impl Backlight
Sourcepub async fn without_display_power() -> Result<Self, Error>
pub async fn without_display_power() -> Result<Self, Error>
Creates a simple Backlight control, for devices on which DDIC power cannot be switched
off and on.
Sourcepub async fn with_display_power(
power_off_delay_millis: u16,
power_on_delay_millis: u16,
) -> Result<Self, Error>
pub async fn with_display_power( power_off_delay_millis: u16, power_on_delay_millis: u16, ) -> Result<Self, Error>
Creates a Backlight control that manages both the backlight brightness/power and the power
state of the DDIC.
pub async fn get_max_absolute_brightness(&self) -> Result<f64, Error>