[][src]Struct lib::config::cli::Config

pub struct Config {
    pub verbose: bool,
    pub excludes: Vec<PathBuf>,
    pub tags: Vec<String>,
    pub dotfiles_path: Option<PathBuf>,
    pub hostname: Option<String>,
    pub command: Command,
}

Fields

verbose: bool

Enables verbose output.

excludes: Vec<PathBuf>

Paths (relative to the dotfiles folder) of items to be excluded. This is in addition to any excludes defined in your dotrc. Globs are accepted - just make sure to enclose them in single quotes to avoid your shell trying to expand them.

tags: Vec<String>

Tags to enable. This is in addition to any tags enabled in your dotrc.

dotfiles_path: Option<PathBuf>

The folder in which to search for dotfiles. The default is ~/.dotfiles.

hostname: Option<String>

The hostname to use. Only one hostname can be used. The default is the system hostname.

command: Command

Methods

impl Config[src]

pub fn get() -> Self[src]