setup_tracing

Function setup_tracing 

pub fn setup_tracing(args: &Args) -> Result<()>
Setup logging to stdout (Tracing is a bit more involving to set up but will provide much more feature if needed)