MMStatus

Struct MMStatus 

pub struct MMStatus {
    pub text: String,
    pub emoji: String,
    pub duration: Option<String>,
    pub expires_at: Option<DateTime<Local>>,
}
Custom struct to serialize the HTTP POST data into a json objecting using serde_json For a description of these fields see the MatterMost OpenApi sources

Fields

text: String

custom status text description

emoji: String

custom status emoji name

duration: Option<String>

custom status duration

expires_at: Option<DateTime<Local>>

custom status expiration

Implementations

Source

impl MMStatus

pub fn new(text: String, emoji: String) -> MMStatus

Create a MMStatus ready to be sent to the mm_base_uri mattermost instance. Authentication is done with the private access token.

pub fn expires_at(&mut self, time_str: &Option<String>)

Add expiration time with the format “hh:mm” to the mattermost custom status

pub fn to_json(&self) -> Result<String, MMSError>

This function is essentially used for debugging or testing

pub fn _send(&self, session: &Box<dyn BaseSession>) -> Result<Response, Error>

Send self custom status once

pub fn send( &mut self, session: &mut Box<dyn BaseSession>, ) -> Result<Response, MMSError>

Send self custom status, trying to login once in case of 401 failure.