Struct lib::mattermost::MMStatus [−][src]
pub struct MMStatus {
pub text: String,
pub emoji: String,
pub duration: Option<String>,
pub expires_at: Option<DateTime<Local>>,
// some fields omitted
}Expand description
Custom struct to serialize the HTTP POST data into a json objecting using serde_json For a description of these fields see the MatterMost OpenApi sources
Fields
text: Stringcustom status text description
emoji: Stringcustom status emoji name
duration: Option<String>custom status duration
expires_at: Option<DateTime<Local>>custom status expiration
Implementations
Create a MMStatus ready to be sent to the mm_base_uri mattermost instance.
Authentication is done with the private access token.
Add expiration time with the format “hh:mm” to the mattermost custom status
This function is essentially used for debugging or testing