[−][src]Struct lib::model::UserQueryBuilder
Fields
name: Option<String>uid: Option<u64>gid: Option<u64>comment: Option<String>home: Option<String>shell: Option<String>Methods
impl UserQueryBuilder[src]
pub const fn new() -> Self[src]
Create a new QueryBuilder. Note that
pub fn build(self) -> Option<impl Query<User>>[src]
Build a [Query<User>], returning None if all elements of the QueryBuilder are None.
pub fn with_name(self, name: &str) -> Self[src]
add a name to the query, replacing it if it already exists.
pub fn with_uid(self, uid: u64) -> Self[src]
add a uid to the query, replacing it if it already exists.
pub fn with_gid(self, gid: u64) -> Self[src]
add a gid to the query, replacing it if it already exists.
pub fn with_comment(self, comment: &str) -> Self[src]
add a comment to the query, replacing it if it already exists.
pub fn with_home(self, home: &str) -> Self[src]
add a home to the query, replacing it if it already exists
pub fn with_shell(self, shell: &str) -> Self[src]
add a shell to the query, replacing it if it already exists