StopSignal

Enum StopSignal 

pub enum StopSignal {
    SIGINT,
    SIGTERM,
    SIGKILL,
    SendKeys(Vec<Key>),
    HardKill,
    Cmd(String),
}

Variants



SIGINT



SIGTERM



SIGKILL



SendKeys(Vec<Key>)



HardKill



Cmd(String)

Run a shell command as the stop action. Useful for tools like podman compose that don’t reliably respond to signals but do have an explicit teardown command (e.g. podman compose down). The main process is expected to exit on its own once the stop command completes (e.g. compose up exits when containers go away).

Implementations

Source

impl StopSignal

pub fn from_val(val: &Val<'_>) -> Result<Self>