Module offtime
lib
0.2.1
Module offtime
Module Items
Structs
Enums
Traits
In crate lib
lib
Module
offtime
This module Provide the
Off
trait and
OffDays
struct
Structs

OffDays
Struct olding a map of (
Weekday
,
Parity
) descripting day offs.
Enums

Parity
Struct for describing the parity of the week for which the out of work day apply Parity is given according to iso week number
Weekday
The day of week.
Traits

Now
Trait providing a
now
function.
Off
Manage the time where the application shall not update the status because the user is not working