pub enum Parity {
EveryWeek,
OddWeek,
EvenWeek,
}Expand description
Struct for describing the parity of the week for which the out of work day apply Parity is given according to iso week number
Variants
EveryWeek
Day off for all weeks
OddWeek
Day off only for odd weeks
EvenWeek
Day off only for even weeks