Off

Trait Off 

pub trait Off {
    // Required method
    fn is_off_time(&self) -> bool;
}
Manage the time where the application shall not update the status because the user is not working

Required Methods

fn is_off_time(&self) -> bool

Is the user off now ?

Implementors