pub struct Template {
pub id: String,
pub contents: String,
pub group: String,
pub context_mode: ContextMode,
pub structure_mode: StructureMode,
pub extension: String,
pub names: Names,
}Expand description
A struct representing a fully configured template.
Fields
id: StringThe template’s id.
This is the file path relative to the templates directory. It serves to identify a template within the registry when rendering.
--> /path/to/templates/nested/template.md
--> nested/template.mdcontents: StringThe unparsed contents of the template.
This gets parsed and validated during template registration.
group: StringThe template’s group name.
See StructureMode::FlatGrouped and StructureMode::NestedGrouped for more information.
context_mode: ContextModeThe template’s context mode i.e what the template intends to render.
See ContextMode for more information.
structure_mode: StructureModeThe template’s structure mode i.e. how the output should be structured.
See StructureMode for more information.
extension: StringThe template’s file extension.
names: NamesThe template strings for generating output file and directory names.
Implementations
Sourceimpl Template
impl Template
Sourcepub fn new<P>(path: P, string: &str) -> Result<Self>
pub fn new<P>(path: P, string: &str) -> Result<Self>
Creates a new instance of Template.
Arguments
path- The path to the template relative to the templates directory.string- The contents of the template file.
Errors
Will return Err if:
- The template’s opening and closing config tags have syntax errors.
- The tempalte’s config has syntax errors or is missing required fields.