Struct lib::Bytes [−][src]
The struct used to store the number of bytes.
Trait bounds specify what traits are required from the type used to store the number of bytes.
Into<u64> in particular is required as the number of bytes is temporarily converted to u64
(the only type that we are sure can store any number stored in another type without overflowing)
to compare it.