Trait lib::Unsigned [−][src]
pub trait Unsigned { }Expand description
Marker trait used to indicate to the compiler what types are allowed to initialize the struct.
pub trait Unsigned { }Marker trait used to indicate to the compiler what types are allowed to initialize the struct.