Automattermostatus main components and helper functions used by main
Re-exports
pub use config::Args;pub use config::SecretType;pub use config::WifiStatusConfig;pub use mattermost::BaseSession;pub use mattermost::MMStatus;pub use mattermost::Session;pub use state::Cache;pub use state::Location;pub use state::State;pub use wifiscan::WiFi;pub use wifiscan::WifiInterface;
Modules
- config
- This module holds struct and helpers for parameters and configuration
- mattermost
- This module exports Session and MMStatus
- offtime
- This module Provide the
Offtrait andOffDaysstruct - state
- Implement persistant state for current location
- utils
- Simple utilities functions
- wifiscan
- Implement wifi SSID scan for linux, windows and mac os.
Functions
- create_
session - Create
Sessionaccording toargs.secret_type. - get_
cache - Return a
Cacheused to persist state. - get_
wifi_ and_ update_ status_ loop - Main application loop, looking for a known SSID and updating mattermost custom status accordingly.
- prepare_
status - Prepare a dictionnary of
MMStatusready to be send to mattermost server depending upon the location being found. - setup_
tracing - Setup logging to stdout (Tracing is a bit more involving to set up but will provide much more feature if needed)