Crate lib[−][src]
Automattermostatus main components and helper functions:
config: allow to configure the application from file and command line,mattermost: updating custom status on a mattermost instance,state: persistent application state (essentially the location),wifiscan: wifi scanning for linux, macos and windowsofftime: management of time when no custom status shall be send
Re-exports
pub use config::Args;pub use config::WifiStatusConfig;pub use mattermost::MMStatus;pub use state::Cache;pub use state::Location;pub use state::State;pub use wifiscan::WiFi;pub use wifiscan::WifiInterface;Modules
This module holds struct and helpers for parameters and configuration
Module responsible for sending custom status change to mattermost.
This module Provide the Off trait and OffDays struct
Implement persistant state for current location
Simple utilities functions
Implement wifi SSID scan for linux, windows and mac os.
Functions
Return a Cache used to persist state.
Main application loop, looking for a known SSID and updating mattermost custom status accordingly.
Prepare a dictionnary of Status ready to be send to mattermost
server depending upon the location being found.
Setup logging to stdout (Tracing is a bit more involving to set up but will provide much more feature if needed)