[−][src]Module lib::common
Modules
| util |
Structs
| AbsolutePath | Represents an (owned) path which must be absolute |
| FormattedItem | Just a wrapper for pretty-printing |
| FormattedItems | |
| Item | Represents the location of a dotfile (the source) and the location of the symlink pointing to the source (the destination) as a pair of absolute paths to the two files. |