[−][src]Module lib::common::util
Enums
| FileType |
Functions
| append_vecs | Efficiently appends two |
| file_type | |
| get_verbosity | |
| home_dir | |
| home_to_tilde | Tries to replace absolute paths of the home directory
with a tilde for readability. If that fails for any reason, just
return |
| is_hidden | Checks if a filename is prefixed by a '.' character. If the path cannot be read as UTF-8, assume it isn't hidden. |
| set_verbosity |