[−][src]Struct lib::config::cli::Config
Fields
verbose: boolEnables verbose output.
excludes: Vec<PathBuf>Paths (relative to the dotfiles folder) of items to be excluded. This is in addition to any excludes defined in your dotrc. Globs are accepted - just make sure to enclose them in single quotes to avoid your shell trying to expand them.
Tags to enable. This is in addition to any tags enabled in your dotrc.
dotfiles_path: Option<PathBuf>The folder in which to search for dotfiles. The default is ~/.dotfiles.
hostname: Option<String>The hostname to use. Only one hostname can be used. The default is the system hostname.
command: CommandMethods
impl Config[src]