Enum lib::config::SecretType
source · [−]pub enum SecretType {
Token,
Password,
}Expand description
Enum used to encode secret_type parameter (password or token)
When set to [Password], the secret is used to obtain a session token by using the login API. When set to [Token], the secret is a private access token directly usable to access API.
Variants
Token
Password
Implementations