pub struct WifiStatusConfig {
    pub wifi_string: String,
    pub emoji: String,
    pub text: String,
}
Status that shall be send when a wifi with wifi_string is being seen.

Fields

wifi_string: String

wifi SSID substring associated to this object custom status

emoji: String

string description of the emoji that will be set as a custom status (like home for :home: mattermost emoji.

text: String

custom status text description