Struct lib::config::WifiStatusConfig
source · [−]Expand description
Status that shall be send when a wifi with wifi_string is being seen.
Fields
wifi_string: Stringwifi SSID substring associated to this object custom status
emoji: Stringstring description of the emoji that will be set as a custom status (like home for
:home: mattermost emoji.
text: Stringcustom status text description