Module lib::offtime[][src]

This module Provide the Off trait and OffDays struct

Structs

Struct olding a map of (Weekday, Parity) descripting day offs.

Enums

Struct for describing the parity of the week for which the out of work day apply Parity is given according to iso week number

The day of week.

Traits

Trait providing a now function.

Manage the time where the application shall not update the status because the user is not working