Enum lib::offtime::Parity [−][src]
pub enum Parity {
EveryWeek,
OddWeek,
EvenWeek,
}Expand description
Struct for describing the parity of the week for which the out of work day apply Parity is given according to iso week number
Variants
Day off for all weeks
Day off only for odd weeks
Day off only for even weeks