pub trait Now {
    fn now(&self) -> Date<Local>;
}
Trait providing a now function.

The use of a trait instead of calling directly Local::now is needed in order to be able to mock time in tests

Required methods

Returns current local time

Implementors