Trait lib::offtime::Off [−][src]
pub trait Off {
fn is_off_time(&self) -> bool;
}Expand description
Manage the time where the application shall not update the status because the user is not working
Required methods
fn is_off_time(&self) -> bool
fn is_off_time(&self) -> bool
Is the user off now ?