Struct lib::Bytes [−][src]
The actual struct.
Trait bounds specify what traits are required from the type used to store the number of bytes.
Into<u64> in particular is required as the number of bytes is temporarily converted to u64
(the only type that we are sure can store any number stored in another type without overflowing)
to compare it.
Tuple Fields
0: UTrait Implementations
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more