Struct lib::CanvasRenderingContext2D[][src]

pub struct CanvasRenderingContext2D {}

Implementations

adds a circular arc to the current sub-path. see CanvasRenderingContext2D.arc

Parameters
  • ‘x’ - the horizontal coordinate of the arc’s center
  • ‘y’ - the vertical coordinate of the arc’s center
  • ‘radius’ - the arc’s radius. Must be positive
  • ‘start_angle’ - the angle at which the arc starts in radians, measured from the positive x-axis
  • ‘end_angle’ - the angle at which the arc ends in radians, measured from the positive x-axis
  • ‘counter_clockwise’ - if true, draws the arc counter-clockwise between the start and end angles

adds a circular arc to the current sub-path, using the given control points and radius. The arc is automatically connected to the path’s latest point with a straight line, if necessary for the specified parameters. see CanvasRenderingContext2D.arcTo

Parameters
  • ‘x1’ - the x-axis coordinate of the first control point
  • ‘y1’ - the y-axis coordinate of the first control point.
  • ‘x2’ - the x-axis coordinate of the second control point
  • ‘y2’ - the y-axis coordinate of the second control point.
  • ‘radius’ - the arc’s radius. Must be positive